import { toNumber } from "./lib";
import NativeString from "./NativeString";
/** StarkString constructor */
declare function starkString(value: string | number | (string | number)[]): StarkString;
declare class StarkString extends NativeString {
    constructor(value: string);
    /** Returns a copy of a StarkString Object */
    clone(): StarkString;
    /** Used for set new string */
    set(value: string): StarkString;
    /** Used for convert Arabic characters to Persian */
    persianChar(): StarkString;
    /** Used for convert any numbers to English */
    englishNumber(): StarkString;
    /** Used for convert Arabic numbers to Persian */
    persianNumber(): StarkString;
    /** Used for convert English numbers to arabic */
    arabicNumber(): StarkString;
    /**
     * Used for Normalize url
     * https://fa.wikipedia.org/wiki/مدیاویکی:Gadget-Extra-Editbuttons-Functions. s
     */
    fixURL(): StarkString;
    /**
     * Used for decode Persian Characters in URL
     * https://fa.wikipedia.org/wiki/مدیاویکی:Gadget-Extra-Editbuttons-Functions. s
     */
    decodeURL(): StarkString;
    /** Used for Change keyboard layout */
    switchKey(): StarkString;
    /** Used for get persian words representation of a number */
    digitsToWords(): StarkString;
    /** Used for Zero-width non-joiner correction */
    halfSpace(): StarkString;
    /** Return true if value is Integer */
    isInteger(): boolean;
    /** Used for validation back card number */
    isValidBankCard(): boolean;
    /** Used for convert to price mode */
    currency(): StarkString;
    /** Remove anything expect numbers */
    parseNumber(options?: Parameters<typeof toNumber>[1]): StarkString;
    /** Convert any char to star ("*") */
    security(): StarkString;
    /** Convert any string to number */
    toStringNumber(options?: Parameters<typeof toNumber>[1]): string;
    /** Convert any string to number */
    toNumber(options?: Parameters<typeof toNumber>[1]): number;
}
export default starkString;
export type { StarkString };
//# sourceMappingURL=index.d.ts.map