"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        if (typeof b !== "function" && b !== null)
            throw new TypeError("Class extends value " + String(b) + " is not a constructor or null");
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var lib_1 = require("./lib");
var NativeString_1 = __importDefault(require("./NativeString"));
/** StarkString constructor */
function starkString(value) {
    if (typeof value === "number" || typeof value === "string")
        value = String(value);
    else if (Array.isArray(value))
        value = value.join("");
    else if (value === undefined || value === null)
        value = "";
    else
        throw new Error("StarkString value must be type of string, number or Array<string|number> instead of ".concat(typeof value));
    return new StarkString(value);
}
var StarkString = /** @class */ (function (_super) {
    __extends(StarkString, _super);
    function StarkString(value) {
        return _super.call(this, value) || this;
    }
    /** Returns a copy of a StarkString Object */
    StarkString.prototype.clone = function () {
        return starkString(this._value);
    };
    /** Used for set new string */
    StarkString.prototype.set = function (value) {
        this._value = String(value);
        return this;
    };
    /** Used for convert Arabic characters to Persian */
    StarkString.prototype.persianChar = function () {
        this._value = (0, lib_1.persianChar)(this.toString());
        return this;
    };
    /** Used for convert any numbers to English */
    StarkString.prototype.englishNumber = function () {
        this._value = (0, lib_1.englishNumber)(this._value);
        return this;
    };
    /** Used for convert Arabic numbers to Persian */
    StarkString.prototype.persianNumber = function () {
        this._value = (0, lib_1.persianNumber)(this._value);
        return this;
    };
    /** Used for convert English numbers to arabic */
    StarkString.prototype.arabicNumber = function () {
        this._value = (0, lib_1.arabicNumber)(this._value);
        return this;
    };
    /**
     * Used for Normalize url
     * https://fa.wikipedia.org/wiki/مدیاویکی:Gadget-Extra-Editbuttons-Functions. s
     */
    StarkString.prototype.fixURL = function () {
        if (!this._value) {
            return this;
        }
        if (/^(wss?(:|\/))/i.test(this._value)) {
            this._value = this._value.replace(/^(ws)?(s)?(:*)(\/+)?/i, "ws$2://");
        }
        else if (/^(ftps?(:|\/))/i.test(this._value)) {
            this._value = this._value.replace(/^(ftp)?(s)?(:*)(\/+)?/i, "ftp$2://");
        }
        else {
            this._value = this._value.replace(/^(http)?(s)?(:*)(\/+)?/i, "http$2://");
        }
        this._value = this._value.replace(/(\/?)$/i, "/");
        return this;
    };
    /**
     * Used for decode Persian Characters in URL
     * https://fa.wikipedia.org/wiki/مدیاویکی:Gadget-Extra-Editbuttons-Functions. s
     */
    StarkString.prototype.decodeURL = function () {
        this._value = (0, lib_1.decodeURL)(this._value);
        return this;
    };
    /** Used for Change keyboard layout */
    StarkString.prototype.switchKey = function () {
        this._value = (0, lib_1.switchKey)(this._value);
        return this;
    };
    /** Used for get persian words representation of a number */
    StarkString.prototype.digitsToWords = function () {
        this._value = (0, lib_1.digitsToWords)(this._value);
        return this;
    };
    /** Used for Zero-width non-joiner correction */
    StarkString.prototype.halfSpace = function () {
        this._value = (0, lib_1.halfSpace)(this._value);
        return this;
    };
    /** Return true if value is Integer */
    StarkString.prototype.isInteger = function () {
        return (0, lib_1.isInteger)(this._value);
    };
    /** Used for validation back card number */
    StarkString.prototype.isValidBankCard = function () {
        return (0, lib_1.isValidBankCard)(this._value);
    };
    /** Used for convert to price mode */
    StarkString.prototype.currency = function () {
        this._value = (0, lib_1.currency)(this._value);
        return this;
    };
    /** Remove anything expect numbers */
    StarkString.prototype.parseNumber = function (options) {
        this.englishNumber();
        this._value = (0, lib_1.toNumber)(this._value, options);
        return this;
    };
    /** Convert any char to star ("*") */
    StarkString.prototype.security = function () {
        this._value = (0, lib_1.security)(this._value);
        return this;
    };
    /** Convert any string to number */
    StarkString.prototype.toStringNumber = function (options) {
        this.parseNumber(options);
        return this._value;
    };
    /** Convert any string to number */
    StarkString.prototype.toNumber = function (options) {
        this.parseNumber(options);
        return Number(this._value);
    };
    return StarkString;
}(NativeString_1.default));
//Expose StarkString
//CommonJS module is defined
exports.default = starkString;
//# sourceMappingURL=index.js.map